stravalib.client.ActivityUploader.update\_from\_response
========================================================

.. currentmodule:: stravalib.client

.. automethod:: ActivityUploader.update_from_response
